/** 
 @file main.js
 
 @brief This file contains implementation of User interface for Motion Detector app.

 @author: Gregor

 @date: 17.06.2013
*/

var fLoading=false;
var oTimedEvent;

Ext.define(
             'DSS.addon.MotionDetector',
             {
               extend : 'DSS.addon.Framework',
               
               fExpertMode:false,
               config : {
                   appName : _('Motion Detector App'),
                   appId : ' md-configurator',
                   appVersion : '1.0.6',
                   appIcon : 'default_icon.png'
               },
               getHelp : function() {
                   return Ext.create('Ext.Component', {
                       whiteSpace : 'normal',
                       padding : '0 20 0 0', //top right bottom left
                       loader : {
                           url : 'locale/' + dss.staticDataModel.activeLanguage + '/help.html',
                           autoLoad : true,
                           disableCaching : false
                       }
                   });
               },

               autoMode:null,
               emailEnabler:null,
               emailAdress:null,
               arraySavedModes:null,
               arraySavedDevices:null,
               arrayModes:null,
               roomLabelControl:null,
               panelGridRooms:null,
               panelGridDevices:null,
               mainAddonPanel:null,
               roomsGrid : null,
               deviceArray:null,
              
               getContent : function() {
                   var me = this;

                   me.arrayModes = new Array(
                               {'modeID':1, 'modeName': _('Corridor light')},
                               {'modeID':2, 'modeName': _('Basement light')},
                               {'modeID':3, 'modeName': _('Stairway light')},
                               {'modeID':4, 'modeName': _('Outdoor light')},
                               {'modeID':5, 'modeName': _('Switch off light')},
                               {'modeID':99, 'modeName': _('Advanced mode')}
                                             );
                   
                   /* getting stored values for room modes*/
                   me.loadModesFromPropertyList();

                   var oConfigRooms = {
                       defaultSortCol : 'roomName',
                       disabledProperty:'disabled', 
                       inactiveDisabledProperty:'checkboxShouldBeEnabled',                      
                       border: false,
                       storeConfig : {
                           storeId : 'deviceStore',
                           fields : [ 
                             { name : 'id'}, { name : 'roomID'}, 
                             { name : 'disabled', sortType: 'asBoolean'}, 
                             { name : 'roomName', sortType : 'asUCText'}, 
                             { name : 'modeID'}, { name : 'modeName'},  
                             { name : 'isOnlyDark'}, { name : 'onlyDark'}, { name : 'onlyDarkTwilightID'},
                             { name : 'isSetAlarm'}, { name : 'setAlarm'},
                             { name : 'isAutoOff'}, { name : 'autoOff'}, {name : 'addittionalSwitchOff'}, { name : 'autoOffTime'},
                             { name : 'additionalOffDelayTime'},
                             { name : 'testMDDevice'},
                             { name : 'checkboxShouldBeEnabled'}
                           ]},
                       columns : [ {
                           header : _('Active'),
                           dataIndex : 'disabled',
                           xtype : 'disabledcolumn',
                           resizable : false,
                           width : 50
                       }, {
                           header : _('Room'),
                           dataIndex : 'roomName',
                           xtype : 'textcolumn',
                           flex: 3
                       }, {
                           header : _('Mode'),
                           dataIndex : 'modeName',
                           xtype : 'textcolumn',
                           flex: 3
                       }, {
                           header : _('Only if dark'),
                           dataIndex : 'onlyDark',
                           xtype : 'textcolumn',
                           width : 120
                       }, {
                           header : _('Alarm mode'),
                           dataIndex : 'setAlarm',
                           xtype : 'textcolumn',
                           width : 120
                       }, {
                           header : _('Auto off'),
                           dataIndex : 'autoOff',
                           xtype : 'textcolumn',
                           width : 120
                       }, {
                           header : _('Additional Switch-off Delay'),
                           dataIndex : 'addittionalSwitchOff',
                           xtype : 'textcolumn',
                           width : 200
                       } ],
                       buttonText : {
                           editButton : _('Edit mode'),
                           disableButton : _('Deactivate mode'),
                           enableButton:_('Activate mode'),
                       },
                       editorConfig : {
                           title : _('Edit Motion Detector Mode'),
                           staticControls : [ { type : 'hidden', id : 'roomID'}, { type : 'hidden', id : 'disabled'}, 
                           { type : 'hidden', id : 'modeID'},
                           { type : 'hidden', id : 'isOnlyDark'}, { type : 'hidden',id : 'onlyDarkTwilightID'}, 
                           { type : 'hidden', id : 'isSetAlarm'},  
                           { type : 'hidden', id : 'isAutoOff'}, { type : 'hidden',id : 'autoOffTime'}, 
                           { type : 'hidden', id : 'additionalOffDelayTime'}, 
                           {
                               type : 'custom',                               
                               id : 'id',
                               control : Ext.create('DSS.component.RoomLabelControl', {})
                           },
                           {
                               type : 'custom',                               
                               id : 'customRoomModeFields',
                               control : Ext.create('DSS.component.RoomFields', {})
                           }, 
                           { type : 'hidden', id : 'testMDDevice'}
                           ]      
                       },
                      listeners : {
                           'loadDataStore' : function(grid) {
                               me.loadRoomsParameter(grid);
                               me.roomsGrid = grid;
                               me.setupTabRooms(); 
                           },
                           'saveEntry' : function(grid, values) 
                           {                 
                             me.waitAndReloadRoomModes(grid, {actions : 'save', value : Ext.JSON.encode(values)});
                           },
                           
                           'disableEntry':function (grid,entry){
                               var idVal;
                               if (entry.get!=null) {
                                idVal=entry.get('id');
                               } 
                               else {
                                idVal=[];
                                for (var iIndex=0;iIndex<entry.length;iIndex++) 
                                 if (entry[iIndex]!=null)
                                  idVal.push(entry[iIndex].get('id'));
                               }
                               me.waitAndReloadRoomModes(grid,{
                                   actions : 'disable',
                                   id : Ext.JSON.encode(idVal)
                               });
                           },
                            
                           'enableEntry':function (grid,entry){
                               var idVal;
                               if (entry.get!=null) {
                                idVal=entry.get('id');
                               } else {
                                idVal=[];
                                for (var iIndex=0;iIndex<entry.length;iIndex++) 
                                 if (entry[iIndex]!=null)
                                  idVal.push(entry[iIndex].get('id'));
                               }
                               me.waitAndReloadRoomModes(grid,{
                                   actions : 'enable',
                                   id : Ext.JSON.encode(idVal)
                               });
                            },                            
                       }                       
                   }
                   
                   var oConfigDevices = {
                       defaultSortCol : 'name',
                       border: false,
                       storeConfig : {
                           storeId : 'deviceStore',
                           fields : [ {
                               name : 'dSUID'
                           }, {
                               name : 'sensorFunction'  // 0 - AppMode, 5 - Motion detector, 4 - Twilight Sensor
                           }, {
                               name : 'deviceInputModeDelay'
                           }, {                  
                               name : 'ZoneID'
                           }, {                  
                               name : 'roomID'
                           }, {
                               name : 'offDelay'
                           }, {
                               name : 'name',
                               sortType : 'asUCText'
                           }, {
                               name : 'room',
                               sortType : 'asUCText'
                           }, {
                               name : 'deviceMDInfo',
                               sortType : 'asUCText'
                           }, {
                               name : 'inputMode',
                               sortType : 'asUCText'
                           }]},
                       columns : [{
                           header : _('Device'),
                           dataIndex : 'dSUID',
                           xtype : 'devicenameshortcolumn', //devicenamecolumn
                           width : 400
                       }, {
                           header : _('dSUID'),
                           dataIndex : 'dSUID',
                           xtype : 'textcolumn',
                           width : 200,
                           customColumnRenderer: function (val, metadata, record, rowIdx, colIdx, store, view) {   
                             return val.slice(val.length-10, val.length-2);
                           }
                       },{
                           header : _('Room'),
                           dataIndex : 'room',
                           xtype : 'textcolumn',
                           width : 100
                       }, {
                           header : _('Sensor Function'),
                           dataIndex : 'deviceMDInfo',
                           xtype : 'textcolumn',
                           width : 200
                       },  {
                           header : _('Input Mode'),
                           dataIndex : 'inputMode',
                           xtype : 'textcolumn',
                           flex : 1
                       } ],
                       buttonText : {
                           editButton : _('Edit device')
                       },
                       editorConfig : {
                           title : _('Device configurator'),
                           staticControls : [ {
                               type : 'hidden',
                               id : 'dSUID'
                           }, {
                               type : 'hidden',
                               id : 'roomID'
                           }, {
                               type : 'hidden',
                               id : 'name',
                           }, {
                               type : 'hidden',
                               id : 'ZoneID',
                           }, {
                               type : 'custom',
                               label : _('Sensor Function'),
                               id : 'sensorFunction',
                               control : Ext.create('DSS.component.DeviceSensorFunction', {}),
                           }, {
                               type : 'custom',
                               label : _('Input Mode'),
                               id : 'deviceInputModeDelay',
                               control : Ext.create('DSS.component.DeviceInputModeDelay', {}),
                           } ]      
                       },
                       listeners : {
                           'loadDataStore' : function(grid) {
                               me.loadDevicesParameter(grid, true);
                           },
                           'saveEntry' : function(grid, values) 
                           {
                             try {
                                 var oDevice=dss.staticDataModel.getDevice(values.dSUID);
                                 if (oDevice != null && 
                                     values.deviceInputModeDelay != null && values.deviceInputModeDelay.isDevicePresent) // storing data to device only when present
                                 {
                                   Ext.Ajax.request({url: "/json/device/setName?newName="+values.sensorFunction.deviceName+"&dsuid="+values.dSUID});
                                  
                                   // Setting device MD status
                                   var nNewMDType = 0;
                                   if (values.sensorFunction.nMode > 0)
                                     nNewMDType = values.sensorFunction.nMode;

                                   if (values.dSUID != null)
                                   {
                                     // Sensor Function
                                     var setURL = "/json/device/setBinaryInputType?index=0&type="+nNewMDType+"&dsuid="+values.dSUID;
                                     {  // excecute script to save MD status
                                       getLatestReq = Ext.Ajax.request({url: setURL});
                                     }
                                     
                                     // input mode
                                     var setInputUrl = "/json/device/setAKMInputProperty?dsuid="+values.dSUID+"&mode=standard";
                                     if (values.deviceInputModeDelay != null && values.deviceInputModeDelay.invertedMode.isInverted == 1)
                                       setInputUrl = "/json/device/setAKMInputProperty?dsuid="+values.dSUID+"&mode=inverted";
                                     getLatestReq = Ext.Ajax.request({url: setInputUrl});  
                                     
                                     // off-delay (converting seconds to miliseconds)
                                     var nOffDelay = 0;
                                     if (values.deviceInputModeDelay != null && values.deviceInputModeDelay.offDelay > 0)
                                       nOffDelay = values.deviceInputModeDelay.offDelay * 1000;
                                     var setTimeoutUrl = "/json/device/setAKMInputTimeouts?dsuid="+values.dSUID+"&offdelay="+nOffDelay;
                                     getLatestReq = Ext.Ajax.request({url: setTimeoutUrl});  

                                     var nDisableOldRoomSR = 0; /* if greater than 0, we pass roomID param*/
                                     var nCopyRoomMode = 0; /* if greater than 0, we use this room mode config to update with new assigned room*/
                                     // test if room has changed
                                     if (values.sensorFunction.roomID != values.sensorFunction.oldRoomID) {
                                       arrayAKM = dss.staticDataModel.getAKMDeviceArray();
                                     
                                       // assigning new room
                                       var setRoomUrl = "/json/structure/zoneAddDevice?deviceID="+values.dSUID+"&zone="+values.sensorFunction.roomID;
                                       getReqData = Ext.Ajax.request({url: setRoomUrl} );  

                                       // test if old room has no more AKM's - disable SR
                                       if (!me.hasRoomAssignedAKM(values.sensorFunction.oldRoomID, arrayAKM, values.dSUID))
                                         nDisableOldRoomSR = values.sensorFunction.oldRoomID;
                                       
                                       // test if new room has only new MD assigned, copy old room mode to new one, create SR
                                       if (me.getRoomAssignedMDCount(values.sensorFunction.roomID, arrayAKM) == 0)
                                         nCopyRoomMode = values.sensorFunction.oldRoomID;
                                     }                        
                                     
                                     dss.raiseEvent('motion-detector.mode-config', {actions : 'deviceupdate', value : Ext.JSON.encode(new Object({'deviceID':values.dSUID,
                                                                                                                                                  'sensorFunction':values.sensorFunction.nMode,
                                                                                                                                                  'inputMode':values.deviceInputModeDelay.invertedMode.isInverted,
                                                                                                                                                  'delayTime':values.deviceInputModeDelay.offDelay,
                                                                                                                                                  'roomID':values.sensorFunction.roomID,
                                                                                                                                                  'disableOldRoomSR':nDisableOldRoomSR,
                                                                                                                                                  'copyRoomMode':nCopyRoomMode
                                                                                                                                                 })
                                                                                                                                     )}) ;
                                                     
                                   }
                               }
                             } 
                             catch (e) {
                             }
                           },
                       }
                   };
                
                   var oRoomsPanel = Ext.create('DSS.gridPanel', oConfigRooms);
                   var oDevicesPanel = Ext.create('DSS.gridPanel', oConfigDevices);
                   oDevicesPanel.editorWindow.setWidth(525); 

                   me.panelGridRooms = Ext.create('Ext.panel.Panel', { id:'pnlModes', title : _('Motion Detector Modes'), layout : 'fit', items : [ oRoomsPanel ]});
                   me.panelGridDevices = Ext.create('Ext.panel.Panel', { itemId:'pnlDevices', title : _('Device Settings'), layout : 'fit', items : [ oDevicesPanel ]});
                   
                   me.mainAddonPanel = Ext.create('Ext.tab.Panel', {layout : 'fit',
                                                                cls:'generalTab',
                                                                items : [me.panelGridRooms, me.panelGridDevices],
                   });
                   me.setupTabRooms();
                
                   return me.mainAddonPanel;
               },
               
               /** 
                @brief Read all stored modes from PropertyList
                
                @param -
                 
                @return Array of stored modes
               */               
               loadModesFromPropertyList: function () {
                   var sString = dss.ajaxSyncRequest('/json/property/query', {
                                                     'query' : '/scripts/motion-detector/modes/*(*)'});
                   var tmpModes = Ext.JSON.decode(sString);
                   if (tmpModes != null && tmpModes.result.modes != null && tmpModes.result.modes.length> 0)  {
                     this.arraySavedModes = tmpModes.result.modes;
                   }
                    
               },
               
               /** 
                @brief Read all stored devices from PropertyList
                
                @param -
                 
                @return Array of stored devices
               */     
               loadDevicesInfoFromPropertyList: function () {
                   var sString = dss.ajaxSyncRequest('/json/property/query', {
                                                'query' : '/scripts/motion-detector/mddevices/*(*)'});
                   var tmpModes = Ext.JSON.decode(sString);
                   if (tmpModes != null && tmpModes.result.mddevices != null && tmpModes.result.mddevices.length> 0)
                     this.arraySavedDevices = tmpModes.result.mddevices;
               },
               
               /** 
                @brief Returns the string name of searched modeID
                
                @param nModeID - ID of mode
                 
                @return Array of stored modes
               */               
               getRoomModeName : function (nModeID) {                     
                 var returnData = _('Advanced mode');
                 if (nModeID > 0 && this.arrayModes != null) {
                   for ( var iIndex = 0; iIndex < this.arrayModes.length; iIndex++) {
                      var oMode = this.arrayModes[iIndex];
                      if (oMode != null && oMode.modeID == nModeID) {
                        returnData = oMode.modeName;
                        break;
                      }
                   } 
                 }
                 return returnData;
               },
               
               /** 
                @brief Returns the all mode data for searched room
                
                @param nRoomID - ID of the room
                 
                @return Array of stored modes
               */               
               getSavedModeData : function (nRoomID) {                     
                 var returnData = null;
                 if (nRoomID > 0 && this.arraySavedModes != null) {
                   for ( var iIndex = 0; iIndex < this.arraySavedModes.length; iIndex++) {
                      var oMode = this.arraySavedModes[iIndex];
                      if (oMode != null && oMode.roomID == nRoomID) {
                        returnData = oMode;
                        break;
                      }
                   } 
                 }
                 return returnData;
               },
               
               /** 
                @brief Returns the all device data for sDeviceID
                
                @param sDeviceID - ID of the searched device
                 
                @return Array of stored modes
               */                    
               getSavedDeviceData : function (sDeviceID) {                     
                 var returnData = null;
                 if (sDeviceID != "" && this.arraySavedDevices != null) {
                   for ( var iIndex = 0; iIndex < this.arraySavedDevices.length; iIndex++) {
                      var oDevice = this.arraySavedDevices[iIndex];
                      if (oDevice != null && oDevice.deviceID == sDeviceID) {
                        returnData = oDevice;
                        break;
                      }
                   } 
                 }
                 return returnData;
               },

               /** 
                @brief Waits until ends script saving data from "Edit Motion Detector Mode" dialog and then realoads grid with new data
                
                @param grid
                 
                @return 
               */               
               waitAndReloadRoomModes : function(grid,parameter) {
                   grid.setStatus(_('Saving ...'));
                   var me = this;
                   
                   var waitDialog = new Ext.LoadMask(Ext.getBody(), {msg:_('Please wait, saving room mode ...'), indicator:false});
                   waitDialog.show();

                   dss.pushAndQuery('system-addon-presence-simulator.holiday-config',parameter,
							'motion-detector-room-mode.saved',function(eventData) {
						me.loadModesFromPropertyList();
	                    me.loadRoomsParameter(grid);
	                    waitDialog.hide();
						return true;
				   });
					
                   
               },  

               /** 
                @brief Waits until ends script saving data from "Device Configurator" dialog and then realoads grid with new data
                
                @param grid
                 
                @return 
               */               
               waitAndReloadDevices : function(grid,parameter) {
                   grid.setStatus(_('Saving ...'));
                   var me = this;
                   
                   dss.pushAndQuery('motion-detector.mode-config',parameter,
							'motion-detector-devices.saved',function(eventData) {
                	   me.loadDevicesParameter(grid, false);

                       if (me.roomsGrid != null) {
                         me.loadModesFromPropertyList();
                         me.loadRoomsParameter(me.roomsGrid);
                         me.setupTabRooms();
                       }

                       me.deviceArray = null;
						return true;
				   });
                                     
               },  
               
               /** 
                @brief Searches specified room for AKM devices 
                
                @param nRoomID - ID of searched room
                 
                @return true - if room has one or more assigned AKM devices set as MD device, otherwise returns false
               */   
               hasRoomAssignedAKM : function(nRoomID, deviceArray, sSkipDeviceID) {
                 var bShow = false;
                 for (var iIndex=0;iIndex<deviceArray.length;iIndex++) {
                   if (deviceArray[iIndex] != null && deviceArray[iIndex].present == true) {
                     var deviceData = deviceArray[iIndex];
                     if (sSkipDeviceID.length == 0 || (sSkipDeviceID.length >0 && sSkipDeviceID != deviceData.dSUID)) {
                       if (deviceData != null && deviceData.ZoneID == nRoomID && deviceData.binaryInputs[0] != null && deviceData.binaryInputs[0].type == 5) {
                         bShow = true;
                         break;
                       }
                     }
                   }
                 }
                 return bShow;
               },
               
             /** 
                @brief 
                
                @param nRoomID - ID of searched room
                 
                @return number of AKM devices set as MD for specified room
               */   
               getRoomAssignedMDCount : function(nRoomID, deviceArray) {
                 var nMDCount = 0;
                 for (var iIndex=0;iIndex<deviceArray.length;iIndex++) {
                   if (deviceArray[iIndex] != null && deviceArray[iIndex].present == true) {
                     var deviceData = deviceArray[iIndex];
                     if (deviceData != null && deviceData.ZoneID == nRoomID && deviceData.binaryInputs[0] != null && deviceData.binaryInputs[0].type == 5) 
                       nMDCount++;
                   }
                 }
                 return nMDCount;
               },    
               
               leadingZero : function (num, places) {
                 var zero = places - num.toString().length + 1;
                 return Array(+(zero > 0 && zero)).join("0") + num;
               },
               
               prepareTime: function(secs) {
                 var hours = Math.floor(secs / (3600));
                
                 var divisor_for_minutes = secs % (3600);
                 var minutes = Math.floor(divisor_for_minutes / 60);     
                
                 var divisor_for_seconds = divisor_for_minutes % 60;
                 var seconds = Math.ceil(divisor_for_seconds);
                 
                 var pTime = new Object();
                 pTime.hours = "00";
                 pTime.minutes = "00";
                 pTime.seconds = "00";
                 
                 if (hours > 0)
                   pTime.hours = this.leadingZero(hours, 2);
                 
                 if (minutes > 0)
                   pTime.minutes = this.leadingZero(minutes, 2);
                
                 if (seconds > 0)
                   pTime.seconds = this.leadingZero(seconds, 2);
                 
                 return pTime;
               },    
           
               
               /** 
                @brief Loads all available rooms to grid. And ands them stored "Mode" configuration parameters
                
                @param grid
                 
                @return 
               */               
               loadRoomsParameter : function(grid) {
                     grid.setStatus(_('Loading ...'));  
                     var roomsGridArray=new Array();
                     var me = this;
                    
                     if (me.deviceArray == null) 
                     {
                         dss.staticDataModel.initDeviceCache();
                         me.deviceArray=dss.staticDataModel.getAKMDeviceArray();
                     }
                    
                     me.bEnableTabRooms = false;
                     if (dss.staticDataModel.nameCache != null) {
                       for ( var iIndex = 0; iIndex < dss.staticDataModel.nameCache.length; iIndex++) {
                          var oZone = dss.staticDataModel.nameCache[iIndex];
                          if (oZone != null && oZone.ZoneID > 0 && me.hasRoomAssignedAKM(oZone.ZoneID, me.deviceArray, '')) {
                            me.bEnableTabRooms = true;
                            var roomData = me.getSavedModeData(oZone.ZoneID);
                            if (roomData == null) { // room mode has not been assigned in this dSS, we must store data to property tree
                              var roomData = new Object();
                              roomData.roomID = oZone.ZoneID;
                              roomData.disabled = false;
                              roomData.modeID = 99;
                              
                              dss.raiseEvent('motion-detector.mode-config', {actions : 'save', value : Ext.JSON.encode(roomData)}); 
                            }
                            
                            if (roomData != null) { 
                              var arrayObject={};

                              arrayObject.id = oZone.ZoneID;                 
                              arrayObject.roomID = oZone.ZoneID;
                              arrayObject.roomName = oZone.name;              
                              arrayObject.disabled = true;                           
                              
                              // default empty values
                              arrayObject.modeID = 99;
                              arrayObject.modeName = _('Advanced mode');
                              arrayObject.isOnlyDark = false;
                              arrayObject.onlyDark = _('N/A'); 
                              arrayObject.onlyDarkTwilightID = -1;
                              arrayObject.isSetAlarm = false
                              arrayObject.setAlarm = _('N/A');
                              arrayObject.isAutoOff = false;
                              arrayObject.autoOff = _('N/A');
                              arrayObject.additionalOffDelayTime = 0;
                              arrayObject.addittionalSwitchOff = _('N/A');
                              
                              // set stored values for room from PropertyTree
                              arrayObject.disabled = roomData.disabled;
                              arrayObject.modeID = roomData.modeID;
                              arrayObject.modeName = me.getRoomModeName(roomData.modeID);
                              
                              if (arrayObject.modeID == 99)
                                arrayObject.checkboxShouldBeEnabled = true;
                              else
                                arrayObject.checkboxShouldBeEnabled = false;
                              
                              if (roomData.modeID > 0 && roomData.modeID < 99)
                              {
                                if (roomData.modeID != 5) // disabled for "Switch off light mode"
                                {
                                  var sStringValue = _('N/A');
                                  arrayObject.isOnlyDark = roomData.switchOffDarkCheck;              
                                  if (roomData.switchOffDarkCheck) {
                                    
                                    if (roomData.switchOffDarkSensorID == 0)
                                      sStringValue = _("Use position of the sun")
                                    else {
                                      for (var yIndex=0;yIndex<me.deviceArray.length;yIndex++) {
                                        if (me.deviceArray[yIndex] != null && me.deviceArray[yIndex].dSUID == roomData.switchOffDarkSensorID) {
                                          sStringValue = me.deviceArray[yIndex].name;
                                          break;
                                        }
                                      }
                                    }
                                  }
                                  else               
                                    sStringValue = _('No');
                                    
                                  // no / use position of the sun / twilight sensor name
                                  arrayObject.onlyDark = sStringValue;
                                  arrayObject.onlyDarkTwilightID = roomData.switchOffDarkSensorID;
                                }
                                
                                if (roomData.modeID != 4) /*&& roomData.modeID != 5)*/ // disabled for "Outdoor light", "Switch off light mode"
                                {
                                  arrayObject.isSetAlarm = roomData.setAlarmCheck;              
                                  if (roomData.setAlarmCheck)
                                    arrayObject.setAlarm = _('Yes');  
                                  else               
                                    arrayObject.setAlarm = _('No');
                                }
                                
                                var sStringValue = _('N/A');
                                arrayObject.isAutoOff = roomData.autoOffCheck;  
                                if (roomData.autoOffCheck) {
                                  var pTime = this.prepareTime(roomData.autoOffDelay);
                                  sStringValue = pTime.hours+":"+pTime.minutes+" "+_("(hh:mm)");
                                }
                                else               
                                  sStringValue = _('No');
                                arrayObject.autoOff = sStringValue;  
                                arrayObject.autoOffTime = roomData.autoOffDelay;
                                arrayObject.additionalOffDelayTime = roomData.additionalOffDelayTime;                          
                                
                                sStringValue = _('N/A');
                                if (roomData.additionalOffDelayTime > 0) {
                                  var pTime = this.prepareTime(roomData.additionalOffDelayTime);
                                  sStringValue = pTime.minutes+":"+pTime.seconds+" "+_("(mm:ss)");
                                }
                                arrayObject.addittionalSwitchOff = sStringValue;
                              }
                               
                              roomsGridArray.push(arrayObject);                 
                            }
                          }
                       } 
                     }  
                     grid.loadParameter(roomsGridArray);
                     
                     grid.setStatus(_('Ready'));
               },
               
               /** 
                @brief Disables/Enables "Motion Detector Modes" tab 
                
                @param 
                 
                @return 
               */   
               setupTabRooms : function() {
                     var me = this;
                     if (me.panelGridRooms != null) {
                       me.panelGridRooms.setDisabled(false);
                       if (!me.bEnableTabRooms) {
                         me.panelGridRooms.setDisabled(true);
                         me.mainAddonPanel.setActiveTab(me.panelGridDevices);
                       }
                     }
               },
               
               /** 
                @brief Loads all available AKM devices to grid with their current settings
                
                @param grid
                 
                @return 
               */               
               loadDevicesParameter : function(grid, clearDevices) {
                     grid.setStatus(_('Loading ...'));  
                     var me = this;
                     
                     // realoding devices from cache
                     if (me.deviceArray == null) 
                     {
                         dss.staticDataModel.initDeviceCache();
                         me.deviceArray=dss.staticDataModel.getAKMDeviceArray();
                     }
                     
                     var deviceActiveArray=new Array();
                     me.loadDevicesInfoFromPropertyList();

                     if (me.deviceArray != null)
                     {
                       for (var iIndex=0;iIndex<me.deviceArray.length;iIndex++) {
                         // adding only present devices
                         if (me.deviceArray[iIndex] != null && me.deviceArray[iIndex].present == true) {
                           var deviceData = me.deviceArray[iIndex];
                         
                           if (deviceData != null && deviceData.binaryInputs[0] != null &&
                               (deviceData.binaryInputs[0].type == 0 || deviceData.binaryInputs[0].type == 4 || deviceData.binaryInputs[0].type == 5)
                              ) { // show only AKM set as app-mode, standard, inverted
                             var arrayObject={};
                             arrayObject.dSUID = deviceData.dSUID;
                           
                             var deviceMDInfo = _('MD Normal');
                             var deviceBinaryInputType = 0;
                             if (deviceData.binaryInputs != null && deviceData.binaryInputs.length>0)
                             {
                               deviceBinaryInputType = deviceData.binaryInputs[0].type;
                               if (deviceBinaryInputType == 5) 
                                 deviceMDInfo = _('MD Motion Detector');
                               else
                                 if (deviceBinaryInputType == 4) 
                                   deviceMDInfo = _('MD Twilight Sensor');
                             }
                             
                             arrayObject.deviceMDInfo = deviceMDInfo;
                             arrayObject.sensorFunction = deviceBinaryInputType;
                                                    
                             var deviceStoredData = me.getSavedDeviceData(deviceData.dSUID); 
                           
                             // input mode
                             arrayObject.inputMode = _('Input Mode Standard');
                             arrayObject.deviceInputMode = false;
                             if (deviceStoredData != null && deviceStoredData.inputMode == true) {
                               arrayObject.deviceInputMode = true;
                               arrayObject.inputMode = _('Input Mode Inverted');
                             }
                             
                             // offDelay  
                             arrayObject.offDelay = 0;
                             if (deviceStoredData != null && deviceStoredData.offDelay > 0) 
                               arrayObject.offDelay = deviceStoredData.offDelay;
                             
                             // roomName
                             var sValue=dss.ajaxSyncRequest('/json/zone/getName',{id:deviceData.ZoneID});
                             var oValue=JSON.parse(sValue);
                             if (oValue!=null && oValue.result!=null) {
                               if (oValue.result.name != '')
                                 arrayObject.room = oValue.result.name;
                               else
                                 arrayObject.room = "#"+deviceData.ZoneID;
                             }                          
                             
                             arrayObject.ZoneID = deviceData.ZoneID
                             arrayObject.roomID = deviceData.ZoneID;
                             arrayObject.name   = deviceData.name
                             deviceActiveArray.push(arrayObject);
                           }
                         }
                       }                    
                       grid.loadParameter(deviceActiveArray);
                       grid.setStatus(_('Ready'));
                     }
                     if (clearDevices)
                       me.deviceArray = null;
               }
             }
          );
          
Ext.onReady(function() {
  dss.buildUpLang(['locale/{languageSuffix}/motion-detector.po']); 
  var mdConfigApp = Ext.create('DSS.addon.MotionDetector');
  mdConfigApp.initPage();
});
